==> esbuild-style-loader-0.3.0.tgz: package/esm/index.js <==
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _async_to_generator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
function _define_property(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _object_spread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _define_property(target, key, source[key]);
        });
    }
    return target;
}
function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);
    if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);
        if (enumerableOnly) {
            symbols = symbols.filter(function(sym) {
                return Object.getOwnPropertyDescriptor(object, sym).enumerable;
            });
        }
        keys.push.apply(keys, symbols);
    }
    return keys;
}
function _object_spread_props(target, source) {
    source = source != null ? source : {};
    if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
        ownKeys(Object(source)).forEach(function(key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
    }
    return target;
}
import PATH from 'path';
import { transform } from 'lightningcss';
import { readFile } from 'fs/promises';
import qs from 'query-string';
import deepmerge from 'deepmerge';
import colors from 'colors';
import { transformLess } from './transform-less';
import { codeWithSourceMap, cssExportsToJs, generateTargets, parsePath, replaceExtension, resolvePath } from './utils';
import { convertLessError } from './less-utils';
import { transformSass } from './transform-sass';
import { convertScssError } from './sass-utils';
colors.enable();
export { transformLess, convertLessError };
const defaultOptions = {
    filter: /\.(css|scss|sass|less)(\?.*)?$/,
    cssModules: {
        pattern: '[local]__[hash]'
    },
    browsers: '> 0.25%, not dead'
};
export const styleLoader = (options = {})=>{
    const opts = deepmerge(defaultOptions, options);
    const targets = generateTargets(opts.browsers);
    const allNamespaces = Array.from(new Set([
        'file'
    ].concat(opts.namespace || [])));
    const getLogger = (build)=>{
        const { logLevel } = build.initialOptions;
        if (logLevel === 'debug' || logLevel === 'verbose') {
            return (...args)=>{
                console.log(`[esbuild-style-loader]`.magenta.bold, ...args);
            };
        }
        return ()=>void 0;
    };
    return {
        name: 'style-loader',
        setup (build) {
            const buildOptions = build.initialOptions;
            const logger = getLogger(build);
            const cwd = process.cwd();
            const styleTransform = function() {
                var _ref = _async_to_generator(function*(filePath) {
                    const extname = PATH.extname(filePath);
                    if (extname === '.less') {
                        return yield transformLess(filePath, {
                            sourcemap: !!buildOptions.sourcemap,
                            alias: buildOptions.alias
                        }).catch((error)=>{
                            logger(`transform less error: ${filePath}`.red.bold);
                            logger(error);
                            throw convertLessError(error);
                        });
                    } else if (extname === '.styl') {
                        // TODO: support stylus
                        throw new Error('stylus is not supported yet');
                    } else if (extname === '.scss' || extname === '.sass') {
                        return yield transformSass(filePath, {
                            sourcemap: !!buildOptions.sourcemap,
                            alias: buildOptions.alias
                        }).catch((error)=>{
                            logger(`transform sass error: ${filePath}`.red.bold);
                            logger(error);
                            throw convertScssError(error, filePath);
                        });
                    } else {
                        const code = yield readFile(filePath, 'utf-8');
                        return {
                            css: code,
                            map: ''
                        };
                    }
                });
                return function styleTransform(filePath) {
                    return _ref.apply(this, arguments);
                };
            }();
            const handleResolve = function() {
                var _ref = _async_to_generator(function*(args) {
                    const { path: fullPath, query } = yield resolvePath(args, build);
                    return {
                        path: fullPath,
                        namespace: 'style-loader',
                        pluginData: {
                            rawPath: args.path,
                            query: qs.parse(query),
                            resolveDir: args.resolveDir
                        }
                    };
                });
                return function handleResolve(args) {
                    return _ref.apply(this, arguments);
                };
            }();
            /**
       * you can use `namespace` to control the order of the plugins
       */ allNamespaces.forEach((namespace)=>{
                build.onResolve({
                    filter: opts.filter,
                    namespace
                }, handleResolve);
            });
            build.onLoad({
                filter: /.*/,
                namespace: 'style-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    let cssContent;
                    let cssSourceMap;
                    let watchImports = [];
                    const pluginData = args.pluginData;
                    let entryContent = cssExportsToJs({}, pluginData.rawPath);
                    // enable css modules
                    // 1. if the file name contains `.modules.` or `.module.`
                    // 2. if the query contains `modules`
                    let styleFile = args.path;
                    const enableCssModules = /\.modules?\.(css|less|sass|scss)/.test(styleFile) || 'modules' in pluginData.query;
                    let result;
                    try {
                        const t = Date.now();
                        result = yield styleTransform(styleFile);
                        logger(`Compile`, PATH.relative(cwd, styleFile).blue.underline, `in ${Date.now() - t}ms`);
                        cssContent = result.css;
                        cssSourceMap = result.map;
                        watchImports = result.imports;
                    } catch (error) {
                        return {
                            errors: [
                                error
                            ],
                            resolveDir: PATH.dirname(styleFile),
                            watchFiles: [
                                styleFile
                            ]
                        };
                    }
                    let transformResult;
                    const watchFiles = [
                        styleFile
                    ];
                    if (watchImports) {
                        watchFiles.push(...watchImports);
                    }
                    try {
                        const t = Date.now();
                        transformResult = transform({
                            targets: targets,
                            inputSourceMap: cssSourceMap,
                            sourceMap: true,
                            filename: styleFile,
                            cssModules: enableCssModules ? opts.cssModules : false,
                            code: Buffer.from(cssContent)
                        });
                        logger(`Transform css in ${Date.now() - t}ms`);
                    } catch (error) {
                        logger(`Transform css error: ${styleFile}`.red.bold);
                        logger(error);
                        const { loc, fileName, source } = error;
                        const lines = source.split('\n');
                        const lineText = lines[loc.line - 1];
                        return {
                            errors: [
                                {
                                    text: error.message,
                                    location: {
                                        file: replaceExtension(fileName, '.css'),
                                        line: loc.line,
                                        column: loc.column,
                                        lineText
                                    }
                                }
                            ],
                            resolveDir: PATH.dirname(styleFile),
                            watchFiles
                        };
                    }
                    const { code, map, exports } = transformResult;
                    if (buildOptions.sourcemap && map) {
                        cssContent = codeWithSourceMap(code.toString(), map.toString());
                    } else {
                        cssContent = code.toString();
                    }
                    if (exports) {
                        entryContent = cssExportsToJs(exports, pluginData.rawPath);
                    }
                    return {
                        contents: entryContent,
                        loader: 'js',
                        pluginName: 'style-loader',
                        resolveDir: pluginData.resolveDir,
                        watchFiles: watchFiles,
                        pluginData: _object_spread_props(_object_spread({}, pluginData), {
                            cssContent
                        }),
                        warnings: result.warnings
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onResolve({
                filter: opts.filter,
                namespace: 'style-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    const parsedPath = parsePath(args.path);
                    const result = yield build.resolve(parsedPath.path, {
                        kind: args.kind,
                        resolveDir: args.resolveDir,
                        importer: args.importer
                    });
                    if (result.errors.length) {
                        return {
                            errors: result.errors,
                            resolveDir: PATH.dirname(args.path),
                            watchFiles: [
                                args.path
                            ]
                        };
                    }
                    return {
                        path: result.path,
                        namespace: 'css-loader',
                        pluginData: args.pluginData,
                        watchFiles: [
                            args.path
                        ]
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onLoad({
                filter: /.*/,
                namespace: 'css-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    const pluginData = args.pluginData;
                    const { cssContent, rawPath } = pluginData;
                    return {
                        contents: cssContent,
                        loader: 'css',
                        resolveDir: PATH.dirname(args.path),
                        watchFiles: [
                            rawPath
                        ]
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onResolve({
                filter: /^\//,
                namespace: 'css-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    if (opts.publicPath) {
                        // absolute files base on publicPath
                        return {
                            path: PATH.join(opts.publicPath, '.' + args.path)
                        };
                    }
                    return {
                        external: true
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
        }
    };
};

==> esbuild-style-loader-0.3.1.tgz: package/esm/index.js <==
function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
    try {
        var info = gen[key](arg);
        var value = info.value;
    } catch (error) {
        reject(error);
        return;
    }
    if (info.done) {
        resolve(value);
    } else {
        Promise.resolve(value).then(_next, _throw);
    }
}
function _async_to_generator(fn) {
    return function() {
        var self = this, args = arguments;
        return new Promise(function(resolve, reject) {
            var gen = fn.apply(self, args);
            function _next(value) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
            }
            function _throw(err) {
                asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
            }
            _next(undefined);
        });
    };
}
function _define_property(obj, key, value) {
    if (key in obj) {
        Object.defineProperty(obj, key, {
            value: value,
            enumerable: true,
            configurable: true,
            writable: true
        });
    } else {
        obj[key] = value;
    }
    return obj;
}
function _object_spread(target) {
    for(var i = 1; i < arguments.length; i++){
        var source = arguments[i] != null ? arguments[i] : {};
        var ownKeys = Object.keys(source);
        if (typeof Object.getOwnPropertySymbols === "function") {
            ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function(sym) {
                return Object.getOwnPropertyDescriptor(source, sym).enumerable;
            }));
        }
        ownKeys.forEach(function(key) {
            _define_property(target, key, source[key]);
        });
    }
    return target;
}
function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);
    if (Object.getOwnPropertySymbols) {
        var symbols = Object.getOwnPropertySymbols(object);
        if (enumerableOnly) {
            symbols = symbols.filter(function(sym) {
                return Object.getOwnPropertyDescriptor(object, sym).enumerable;
            });
        }
        keys.push.apply(keys, symbols);
    }
    return keys;
}
function _object_spread_props(target, source) {
    source = source != null ? source : {};
    if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
        ownKeys(Object(source)).forEach(function(key) {
            Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
    }
    return target;
}
import { readFile } from 'node:fs/promises';
import PATH from 'node:path';
import colors from 'colors';
import deepmerge from 'deepmerge';
import { transform } from 'lightningcss';
import qs from 'query-string';
import { convertLessError } from './less-utils.js';
import { convertScssError } from './sass-utils.js';
import { transformLess } from './transform-less.js';
import { transformSass } from './transform-sass.js';
import { codeWithSourceMap, cssExportsToJs, generateTargets, parsePath, replaceExtension, resolvePath } from './utils.js';
colors.enable();
export { transformLess, convertLessError };
const defaultOptions = {
    filter: /\.(css|scss|sass|less)(\?.*)?$/,
    cssModules: {
        pattern: '[local]__[hash]'
    },
    browsers: '> 0.25%, not dead'
};
export const styleLoader = (options = {})=>{
    const opts = deepmerge(defaultOptions, options);
    const targets = generateTargets(opts.browsers);
    const allNamespaces = Array.from(new Set([
        'file'
    ].concat(opts.namespace || [])));
    const getLogger = (build)=>{
        const { logLevel } = build.initialOptions;
        if (logLevel === 'debug' || logLevel === 'verbose') {
            return (...args)=>{
                console.log('[esbuild-style-loader]'.magenta.bold, ...args);
            };
        }
        return ()=>void 0;
    };
    return {
        name: 'style-loader',
        setup (build) {
            const buildOptions = build.initialOptions;
            const logger = getLogger(build);
            const cwd = process.cwd();
            const styleTransform = function() {
                var _ref = _async_to_generator(function*(filePath) {
                    const extname = PATH.extname(filePath);
                    if (extname === '.less') {
                        return yield transformLess(filePath, {
                            sourcemap: !!buildOptions.sourcemap,
                            alias: buildOptions.alias
                        }).catch((error)=>{
                            logger(`transform less error: ${filePath}`.red.bold);
                            logger(error);
                            throw convertLessError(error);
                        });
                    }
                    if (extname === '.styl') {
                        // TODO: support stylus
                        throw new Error('stylus is not supported yet');
                    }
                    if (extname === '.scss' || extname === '.sass') {
                        return yield transformSass(filePath, {
                            sourcemap: !!buildOptions.sourcemap,
                            alias: buildOptions.alias
                        }).catch((error)=>{
                            logger(`transform sass error: ${filePath}`.red.bold);
                            logger(error);
                            throw convertScssError(error, filePath);
                        });
                    }
                    const code = yield readFile(filePath, 'utf-8');
                    return {
                        css: code,
                        map: ''
                    };
                });
                return function styleTransform(filePath) {
                    return _ref.apply(this, arguments);
                };
            }();
            const handleResolve = function() {
                var _ref = _async_to_generator(function*(args) {
                    const { path: fullPath, query } = yield resolvePath(args, build);
                    return {
                        path: fullPath,
                        namespace: 'style-loader',
                        pluginData: {
                            rawPath: args.path,
                            query: qs.parse(query),
                            resolveDir: args.resolveDir
                        }
                    };
                });
                return function handleResolve(args) {
                    return _ref.apply(this, arguments);
                };
            }();
            /**
       * you can use `namespace` to control the order of the plugins
       */ for (const namespace of allNamespaces){
                build.onResolve({
                    filter: opts.filter,
                    namespace
                }, handleResolve);
            }
            build.onLoad({
                filter: /.*/,
                namespace: 'style-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    let cssContent;
                    let cssSourceMap;
                    let watchImports = [];
                    const pluginData = args.pluginData;
                    let entryContent = cssExportsToJs({}, pluginData.rawPath);
                    // enable css modules
                    // 1. if the file name contains `.modules.` or `.module.`
                    // 2. if the query contains `modules`
                    const styleFile = args.path;
                    const enableCssModules = /\.modules?\.(css|less|sass|scss)/.test(styleFile) || 'modules' in pluginData.query;
                    let result;
                    try {
                        const t = Date.now();
                        result = yield styleTransform(styleFile);
                        logger('Compile', PATH.relative(cwd, styleFile).blue.underline, `in ${Date.now() - t}ms`);
                        cssContent = result.css;
                        cssSourceMap = result.map;
                        watchImports = result.imports;
                    } catch (error) {
                        return {
                            errors: [
                                error
                            ],
                            resolveDir: PATH.dirname(styleFile),
                            watchFiles: [
                                styleFile
                            ]
                        };
                    }
                    let transformResult;
                    const watchFiles = [
                        styleFile
                    ];
                    if (watchImports) {
                        watchFiles.push(...watchImports);
                    }
                    try {
                        const t = Date.now();
                        transformResult = transform({
                            targets: targets,
                            inputSourceMap: cssSourceMap,
                            sourceMap: true,
                            filename: styleFile,
                            cssModules: enableCssModules ? opts.cssModules : false,
                            code: Buffer.from(cssContent)
                        });
                        logger(`Transform css in ${Date.now() - t}ms`);
                    } catch (error) {
                        logger(`Transform css error: ${styleFile}`.red.bold);
                        logger(error);
                        const { loc, fileName, source } = error;
                        const lines = source.split('\n');
                        const lineText = lines[loc.line - 1];
                        return {
                            errors: [
                                {
                                    text: error.message,
                                    location: {
                                        file: replaceExtension(fileName, '.css'),
                                        line: loc.line,
                                        column: loc.column,
                                        lineText
                                    }
                                }
                            ],
                            resolveDir: PATH.dirname(styleFile),
                            watchFiles
                        };
                    }
                    const { code, map, exports } = transformResult;
                    if (buildOptions.sourcemap && map) {
                        cssContent = codeWithSourceMap(code.toString(), map.toString());
                    } else {
                        cssContent = code.toString();
                    }
                    if (exports) {
                        entryContent = cssExportsToJs(exports, pluginData.rawPath);
                    }
                    return {
                        contents: entryContent,
                        loader: 'js',
                        pluginName: 'style-loader',
                        resolveDir: pluginData.resolveDir,
                        watchFiles: watchFiles,
                        pluginData: _object_spread_props(_object_spread({}, pluginData), {
                            cssContent
                        }),
                        warnings: result.warnings
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onResolve({
                filter: opts.filter,
                namespace: 'style-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    const parsedPath = parsePath(args.path);
                    const result = yield build.resolve(parsedPath.path, {
                        kind: args.kind,
                        resolveDir: args.resolveDir,
                        importer: args.importer
                    });
                    if (result.errors.length) {
                        return {
                            errors: result.errors,
                            resolveDir: PATH.dirname(args.path),
                            watchFiles: [
                                args.path
                            ]
                        };
                    }
                    return {
                        path: result.path,
                        namespace: 'css-loader',
                        pluginData: args.pluginData,
                        watchFiles: [
                            args.path
                        ]
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onLoad({
                filter: /.*/,
                namespace: 'css-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    const pluginData = args.pluginData;
                    const { cssContent, rawPath } = pluginData;
                    return {
                        contents: cssContent,
                        loader: 'css',
                        resolveDir: PATH.dirname(args.path),
                        watchFiles: [
                            rawPath
                        ]
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
            build.onResolve({
                filter: /^\//,
                namespace: 'css-loader'
            }, function() {
                var _ref = _async_to_generator(function*(args) {
                    if (opts.publicPath) {
                        // absolute files base on publicPath
                        return {
                            path: PATH.join(opts.publicPath, `.${args.path}`)
                        };
                    }
                    return {
                        external: true
                    };
                });
                return function(args) {
                    return _ref.apply(this, arguments);
                };
            }());
        }
    };
};
